##  Updating Your User Profile
To update your profile, in the user profile menu, select My Settings. On the Profile page, you can:
  * View your user details: email, last login, name, and user role
  * Select your workspace language
  * Change your profile picture
